# City of Grand Rapids GIS Functions
This package includes functions to perform GIS operations using the City of Grand Rapids ArcGIS API
#### Functions Included
* Geocode Address Data
* Label Points Based on Polygon Data
